@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# Last Edit: 2013 May 30, 02:02:47 PM
+# Last Edit: 2014 Jan 14, 01:12:46 PM
 # $Id: /dic/branches/ctest/grade 1160 2007-03-29T09:31:06.466606Z greg  $
 
 use strict;
@@ -226,7 +226,7 @@ $report->{grades} = join '', @adjustedReport;
 
 $report->{autogen} = "% This file, report.tex was autogenerated on " . localtime() . "by grader.pl out of report.tmpl";
 my $template = Text::Template->new(	TYPE => 'FILE',
-					SOURCE => '../../class/tmpl/report.tmpl',
+					SOURCE => '../../../class/tmpl/report.tmpl',
 					DELIMITERS => [ '<TMPL>', '</TMPL>' ] );
 open TEX, ">report.tex";
 print TEX $template->fill_in( HASH => $report );
